#!/usr/bin/python

import datetime, re, os.path
import matplotlib
import parser as log_parser

def main():
    from optparse import OptionParser
    parser = OptionParser()
    parser.add_option( "-o", "--output-file", action="store",
            help="Send output to file instead of the screen." )
    parser.add_option( "-i", "--interval", action="store",
            default="5",
            help="Smallest data interval to plot, in minutes." )
    (options, args) = parser.parse_args()

    if options.output_file:
        format = os.path.splitext(options.output_file)[1][1:]
        matplotlib.use(format)
    else:
        format = None

    options.interval = int( options.interval )

    from matplotlib import pyplot

    data = []
    for file in args:
        data += log_parser.parse( file )

    data.sort()
    data = log_parser.smooth( data, options.interval * 60 )

    dates = [ x[ 0 ] for x in data ]
    sensor0 = [ x[ 1 ] for x in data ]
    sensor1 = [ x[ 2 ] for x in data ]
    pyplot.ylabel( "temperature (F)" )
    pyplot.xlabel( "time" )
    pyplot.plot( dates, sensor0, dates, sensor1 )
    if options.output_file:
        pyplot.savefig(options.output_file, format=format)
    else:
        pyplot.show()

if __name__ == "__main__":
    import sys
    sys.exit( main() )
