#!/usr/bin/python

import datetime, re, os.path
import parser as log_parser

def print_extremes( date, extremes ):
    print date.date(),
    for sensor in sorted( extremes ):
        extremes[ sensor ][ 'avg' ] = extremes[ sensor ][ 'sum' ] / \
                extremes[ sensor ][ 'samples' ]
        del extremes[ sensor ][ 'sum' ]
        del extremes[ sensor ][ 'samples' ]
        print "\t%d:" % sensor,
        print ", ".join( [ "%s=%5.1f" % ( key, extremes[ sensor ][ key ] ) \
                for key in extremes[ sensor ]] ),
    print

def main():
    from optparse import OptionParser
    parser = OptionParser()
    (options, args) = parser.parse_args()

    data = []
    for file in args:
        data += log_parser.parse( file )

    data.sort()
    data = log_parser.smooth( data, 300 )

    current_date = None
    sensor_data = [ 0, 0 ]
    for date, sensor_data[ 0 ], sensor_data[ 1 ] in data:
        # Only look at 8am--8pm
#        if date.time() < datetime.time(8, 0, 0) or \
#                date.time() > datetime.time(20, 0, 0):
#            continue

        # Only look at 8am -- 7pm
        if date.time() < datetime.time(8, 0, 0) or \
                date.time() > datetime.time(19, 0, 0):
            continue

        if current_date is None or date.date() != current_date.date():
            if not current_date is None:
                print_extremes( current_date, extremes )
            extremes = {
                0: { 'min': 1e9, 'max': -1e9, 'sum': 0, 'samples': 0 },
                1: { 'min': 1e9, 'max': -1e9, 'sum': 0, 'samples': 0 } }

        for i in range( 2 ):
            extremes[ i ][ 'min' ] = min( extremes[ i ][ 'min' ], sensor_data[ i ])
            extremes[ i ][ 'max' ] = max( extremes[ i ][ 'max' ], sensor_data[ i ])
            extremes[ i ][ 'sum' ] += sensor_data[ i ]
            extremes[ i ][ 'samples' ] += 1
        current_date = date

    print_extremes( date, extremes )

if __name__ == "__main__":
    import sys
    sys.exit( main() )
